@@ -20,11 +20,25 @@
  *   License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 #include "primitivearraydata.h"
-#include "../datainformation.h"
+#include "arraydatainformation.h"
 #include "../primitive/primitivedatainformation.h"
+#include "../../script/scriptlogger.h"
 
 #include <abstractbytearraymodel.h>
 
+#include <limits>
+#include <KLocalizedString>
+
+
+template<PrimitiveDataTypeEnum type>
+inline PrimitiveArrayData<type>::PrimitiveArrayData(unsigned int initialLength, PrimitiveDataInformation* childType,
+        ArrayDataInformation* parent)
+        : AbstractArrayData(childType, parent), mNumReadValues(0), mDummy(parent)
+{
+    Q_ASSERT(childType->type() == type);
+    mData.reserve(initialLength);
+    mData.resize(initialLength);
+}
 
 template<PrimitiveDataTypeEnum type>
 qint64 PrimitiveArrayData<type>::readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
@@ -37,13 +51,13 @@ qint64 PrimitiveArrayData<type>::readData(Okteta::AbstractByteArrayModel* input,
     const quint64 maxRemaining = (bitsRemaining / 8) / sizeof(T);
     //since its 64 bits may be larger than a 32 bit value and have all lower 32 bits as zero
     //therefore we use std::numeric_limits::max()
-    const quint32 maxRemaining32 = (maxRemaining > std::numeric_limits<quint32>::max())
-            ? std::numeric_limits<quint32>::max() : quint32(maxRemaining);
+    quint32 maxRemaining32 = (maxRemaining > std::numeric_limits<quint32>::max()
+            ? std::numeric_limits<quint32>::max() : quint32(maxRemaining));
     const quint32 maxNumItems = qMin(this->length(), maxRemaining32);
     if (maxNumItems == 0)
         return -1; //reached EOF
-    const ByteOrder byteOrder = AbstractArrayData::mParent->effectiveByteOrder();
-    const bool littleEndian = byteOrder == ByteOrderEnumClass::LittleEndian;
+    const QSysInfo::Endian byteOrder = AbstractArrayData::mParent->effectiveByteOrder();
+    const bool littleEndian = byteOrder == QSysInfo::LittleEndian;
 #if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
     if (littleEndian)
         this->readDataNativeOrder(maxNumItems, input, address);
@@ -98,17 +112,24 @@ bool PrimitiveArrayData<type>::setChildData(uint row, QVariant value, Okteta::Ab
         Okteta::Address address, BitCount64 bitsRemaining)
 {
     Q_ASSERT(row < length());
+    Q_ASSERT(value.isValid());
     Q_ASSERT(bitsRemaining % 8 == 0);
     if ((row + 1) * sizeof(T) * 8 >= bitsRemaining)
     {
-        kDebug() << AbstractArrayData::mParent->fullObjectPath() << " not enough bits remaining ("
+        this->mParent->logInfo() << " not enough bits remaining ("
                 << bitsRemaining << ") need " << ((row + 1) * sizeof(T) * 8);
         return false;
     }
-    ByteOrder byteOrder =  AbstractArrayData::mParent->effectiveByteOrder();
-    bool littleEndian = byteOrder == ByteOrderEnumClass::LittleEndian;
-    T convertedVal = DisplayClass::fromVariant(value);
-    kDebug() << AbstractArrayData::mParent->fullObjectPath() << "setting index" << row << "to" << value << "(= " << convertedVal << ")";
+    QSysInfo::Endian byteOrder =  AbstractArrayData::mParent->effectiveByteOrder();
+    bool littleEndian = byteOrder == QSysInfo::LittleEndian;
+    bool ok = false;
+    T convertedVal = DisplayClass::fromVariant(value, &ok);
+    if (!ok) {
+        this->mParent->logWarn() << "could not convert" << value << "to" << type;
+        return false;
+    }
+    kDebug() << AbstractArrayData::mParent->fullObjectPath() << "setting index" << row << "to"
+            << value << "(= " << convertedVal << ")";
     this->mData[row] = convertedVal;
     this->writeOneItem(convertedVal, address + (row * sizeof(T)), out, littleEndian);
     return true;
@@ -161,9 +182,9 @@ void PrimitiveArrayData<Type_Double>::writeOneItem(double value, Okteta::Address
 }
 
 template<PrimitiveDataTypeEnum type>
-QVariant PrimitiveArrayData<type>::dataAt(int index, int column, int role)
+QVariant PrimitiveArrayData<type>::dataAt(uint index, int column, int role)
 {
-    Q_ASSERT(index >= 0 && (unsigned)index < length());
+    Q_ASSERT(index < length());
     if (role == Qt::DisplayRole)
     {
         if (column == DataInformation::ColumnName)
@@ -172,14 +193,15 @@ QVariant PrimitiveArrayData<type>::dataAt(int index, int column, int role)
             return PrimitiveType::typeName(type);
         if (column == DataInformation::ColumnValue)
         {
+            //if we are outside the valid range
             if (uint(index) >= this->mNumReadValues)
-            {
-                //we are outside the valid range
-                return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-            }
-            return DisplayClass::valueString(mData.at(index));
+                return DataInformation::eofReachedData(Qt::DisplayRole);
+            else
+                return DisplayClass::staticValueString(mData.at(index));
         }
     }
+    if (column == DataInformation::ColumnValue && uint(index) >= this->mNumReadValues)
+        return DataInformation::eofReachedData(role);
     return QVariant();
 }
 
@@ -193,16 +215,19 @@ QString PrimitiveArrayData<type>::typeName() const
 template<PrimitiveDataTypeEnum type>
 int PrimitiveArrayData<type>::indexOf(const DataInformation* data) const
 {
-    Q_UNUSED(data);
+    if (data == &mDummy)
+        return this->mDummy.dummyIndex();
     Q_ASSERT_X(false, "PrimitiveArrayData::indexOf", "This should never be called");
-    return 0;
+    return -1;
 }
 
 template<PrimitiveDataTypeEnum type>
 QScriptValue PrimitiveArrayData<type>::toScriptValue(uint index, QScriptEngine* engine, ScriptHandlerInfo* handlerInfo) const
 {
     Q_ASSERT(index < length());
-    return DisplayClass::asScriptValue(mData.at(index), engine, handlerInfo);
+    mChildType->mWasAbleToRead = this->mNumReadValues > index;
+    mChildType->asPrimitive()->setValue(this->mData.at(index));
+    return mChildType->toScriptValue(engine, handlerInfo);
 
 }
 
