@@ -34,9 +34,10 @@ class PrimitiveArrayData : public AbstractArrayData
     Q_DISABLE_COPY(PrimitiveArrayData)
 public:
     typedef typename PrimitiveInfo<type>::valueType T;
-    typedef typename PrimitiveInfo<type>::Class DisplayClass;
+    typedef typename PrimitiveInfo<type>::Methods DisplayClass;
 
-    explicit PrimitiveArrayData(unsigned int initialLength, DataInformation* parent);
+    explicit PrimitiveArrayData(unsigned int initialLength, PrimitiveDataInformation* childType,
+            ArrayDataInformation* parent);
     virtual ~PrimitiveArrayData();
 
     virtual qint64 readData(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
@@ -45,15 +46,14 @@ public:
             Okteta::Address address, BitCount64 bitsRemaining);
 
     virtual DataInformation* childAt(unsigned int idx);
-    virtual QVariant dataAt(int index, int column, int role);
+    virtual QVariant dataAt(uint index, int column, int role);
     AllPrimitiveTypes valueAt(int index) const;
     virtual int indexOf(const DataInformation* data) const;
     virtual unsigned int length() const;
     virtual void setLength(uint newLength);
-    virtual BitCount32 offset(uint row) const;
+    virtual BitCount64 offset(const DataInformation* child) const;
     virtual BitCount32 size() const;
     virtual PrimitiveDataType primitiveType() const;
-    virtual void setParent(DataInformation* parent);
     virtual BitCount32 sizeAt(uint index);
     virtual Qt::ItemFlags childFlags(int row, int column, bool fileLoaded);
 
@@ -73,20 +73,13 @@ protected:
     void readDataNativeOrder(uint numItems, Okteta::AbstractByteArrayModel* input, Okteta::Address addr);
     /** reads @p numItems items from the input, sizes must have been checked before calling this method!! */
     void readDataNonNativeOrder(uint numItems, Okteta::AbstractByteArrayModel* input, Okteta::Address addr);
+    virtual void setNewParentForChildren();
 
     QVector<T> mData;
     uint mNumReadValues; //the number of values read before EOF
-    QScopedPointer<DummyDataInformation> mDummy;
+    DummyDataInformation mDummy;
 };
 
-//constructors
-template<PrimitiveDataTypeEnum type>
-inline PrimitiveArrayData<type>::PrimitiveArrayData(unsigned int initialLength, DataInformation* parent)
-        : AbstractArrayData(parent), mNumReadValues(0), mDummy(new DummyDataInformation(parent))
-{
-    mData.reserve(initialLength);
-    mData.resize(initialLength);
-}
 
 template<PrimitiveDataTypeEnum type>
 inline PrimitiveArrayData<type>::~PrimitiveArrayData()
@@ -94,15 +87,10 @@ inline PrimitiveArrayData<type>::~PrimitiveArrayData()
 }
 
 template<PrimitiveDataTypeEnum type>
-inline void PrimitiveArrayData<type>::setParent(DataInformation* parent)
-{
-    mParent = parent;
-    mDummy->setParent(parent);
-}
-
-template<PrimitiveDataTypeEnum type>
-inline BitCount32 PrimitiveArrayData<type>::offset(uint index) const
+inline BitCount64 PrimitiveArrayData<type>::offset(const DataInformation* data) const
 {
+    Q_ASSERT(data->isDummy());
+    const uint index = data->asDummy()->dummyIndex();
     Q_ASSERT(index < length());
     return index * sizeof(T) * 8;
 }
@@ -112,7 +100,14 @@ inline DataInformation* PrimitiveArrayData<type>::childAt(unsigned int idx)
 {
     Q_ASSERT(idx < length());
     Q_UNUSED(idx);
-    return mDummy.data();
+    mDummy.setDummyIndex(idx);
+    mDummy.setName(QString::number(idx));
+    return &mDummy;
+}
+
+template<PrimitiveDataTypeEnum type>
+inline void PrimitiveArrayData<type>::setNewParentForChildren()
+{
 }
 
 template<PrimitiveDataTypeEnum type>
@@ -130,7 +125,6 @@ inline BitCount32 PrimitiveArrayData<type>::size() const
 template<PrimitiveDataTypeEnum type>
 void PrimitiveArrayData<type>::setLength(uint newLength)
 {
-    Q_ASSERT(newLength >= 0);
     mData.resize(newLength);
     mData.squeeze();
 }
@@ -173,8 +167,4 @@ AllPrimitiveTypes PrimitiveArrayData<type>::valueAt(int index) const
     return AllPrimitiveTypes(mData.at(index));
 }
 
-
-
-
-
 #endif // PRIMITIVEARRAYDATA_H
