@@ -24,34 +24,53 @@
 
 //Qt core
 #include <QString>
+#include <QPair>
+#include <QScopedPointer>
+#include <QMetaType>
 
 //Okteta
 #include <size.h>
 #include <address.h>
 
-#include "structviewpreferences.h"
 #include "datainformationbase.h"
+#include "../script/scriptlogger.h"
+#include "primitivedatatype.h"
 
-#define DATAINFORMATION_CLONE(type) virtual inline type##DataInformation* clone() const {\
-        return new type##DataInformation(*this); \
-    }
+/** Implement the clone() method and add the copy constructor declaration
+ * After this macro visibility will be set to protected */
+#define DATAINFORMATION_CLONE_DECL(type, supertype) public: \
+        virtual inline type* clone() const { return new type(*this); } \
+    protected: \
+        type(const type& d)
+
+/** Implements the clone() method and add the start of the copy constructor (up to delegating).
+ *  After this macro visibility will be set to protected */
+#define DATAINFORMATION_CLONE(type, supertype) DATAINFORMATION_CLONE_DECL(type, supertype) : supertype(d)
 
 namespace Okteta
 {
 class AbstractByteArrayModel;
 }
 
-class TopLevelDataInformation;
-class ScriptHandlerInfo;
 class QScriptContext;
 class QScriptEngine;
 class QScriptValue;
+class QScriptClass;
+class QVariant;
+class QWidget;
 class ScriptLogger;
 class AdditionalData;
+class TopLevelDataInformation;
+class ScriptHandlerInfo;
 
 /** Interface that must be implemented by all datatypes */
 class DataInformation : public DataInformationBase
 {
+    friend class ScriptHandler; //so mHasBeenUpdated/hasBeenValidated can be set
+    friend class PrimitiveDataInformationWrapper; //to set mHasBeenUpdated
+    friend class PointerDataInformation; //to set mWasAbleToRead on pointer target
+    friend class DefaultScriptClass; //to set mValidationSucessful and validationError
+    template<PrimitiveDataTypeEnum type> friend class PrimitiveArrayData; //to set mWasAbleToRead (when returning a script value)
 protected:
     explicit DataInformation(const DataInformation&);
 
@@ -70,29 +89,33 @@ public:
     };
 
     //methods for children:
-    virtual bool hasChildren() const;
     /** true for unions and structs and arrays*/
-    virtual bool canHaveChildren() const;
-    virtual unsigned int childCount() const;
-    virtual DataInformation* childAt(unsigned int) const;
+    virtual bool canHaveChildren() const = 0;
+    virtual unsigned int childCount() const = 0;
+    virtual DataInformation* childAt(unsigned int) const = 0;
     /** @brief Looks for a child of this object with given name
      *  @param name The name of the child to find
      *  @return the child with given @p name or @c NULL if none found with that name
      */
-    virtual DataInformation* child(QString name) const;
-    virtual BitCount32 positionRelativeToRoot(int row = -1) const;
+    virtual DataInformation* child(const QString& name) const;
+    /**
+     * @param start the starting address of the whole structure
+     * @return the position in the file where this element is located
+     */
+    virtual BitCount64 positionInFile(Okteta::Address start) const;
+    /**
+     * @param child the direct child we want to find the address for
+     * @param start the start of the root element
+     * @return the address of @p child in the file
+     */
+    virtual BitCount64 childPosition(const DataInformation* child, Okteta::Address start) const = 0;
 
     //for the model:
     virtual Qt::ItemFlags flags(int column, bool fileLoaded = true) const;
     int row() const;
     /** get the necessary data (for the model) */
     virtual QVariant data(int column, int role) const;
-    /** the data of child at index @p row. Useful for arrays, or DataInformations with fake children*/
-    virtual QVariant childData(int row, int column, int role) const;
-    virtual Qt::ItemFlags childFlags(int row, int column, bool fileLoaded = true) const;
-    virtual BitCount32 childSize(uint index) const = 0;
 
-    /** The size of this DataInformation type in bits (to allow bitfields in future) */
     virtual QString typeName() const = 0;
     /** by default just returns an empty QString */
     virtual QString valueString() const;
@@ -110,13 +133,6 @@ public:
     /** initialize the delegate widget with the correct data */
     virtual void setWidgetData(QWidget* w) const = 0;
 
-    /** create a QWidget for the QItemDelegate */
-    virtual QWidget* createChildEditWidget(uint index, QWidget* parent) const;
-    /** get the needed data from the widget */
-    virtual QVariant dataFromChildWidget(uint index, const QWidget* w) const;
-    /** initialize the delegate widget with the correct data */
-    virtual void setChildWidgetData(uint index, QWidget* w) const;
-
     //reading and writing
     /** the size in bits of this element */
     virtual BitCount32 size() const = 0;
@@ -148,8 +164,6 @@ public:
      */
     virtual bool setData(const QVariant& value, Okteta::AbstractByteArrayModel* out,
             Okteta::Address address, BitCount64 bitsRemaining, quint8 bitOffset) = 0;
-    virtual bool setChildData(uint row, const QVariant& value, Okteta::AbstractByteArrayModel* out,
-            Okteta::Address address, BitCount64 bitsRemaining, quint8 bitOffset) = 0;
 
     virtual bool isTopLevel() const;
     TopLevelDataInformation* topLevelDataInformation() const;
@@ -160,47 +174,62 @@ public:
     QScriptValue validationFunc() const;
     void setValidationFunc(const QScriptValue& func);
     QString validationError() const;
-    void setValidationError(QString errorMessage);
     void unsetValidationError();
     bool validationSuccessful() const;
-    void setValidationSuccessful(bool validationSuccessful = true);
 
+    bool hasBeenUpdated() const;
     bool hasBeenValidated() const;
-    void setHasBeenValidated(bool hasBeen);
     DataInformationEndianess byteOrder() const;
-    ByteOrder effectiveByteOrder() const;
+    QSysInfo::Endian effectiveByteOrder() const;
     void setByteOrder(DataInformationEndianess newEndianess);
     QString fullObjectPath() const;
 
     virtual void resetValidationState(); //virtual for DataInformationWithChildren
     bool wasAbleToRead() const;
-    virtual QScriptValue toScriptValue(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo) = 0;
+    /**
+     * This method is virtual since DummyDataInformation has to override it.
+     *
+     * @param engine the script engine
+     * @param handlerInfo the object holding the script classes
+     * @return a QScriptValue wrapping this object
+     */
+    virtual QScriptValue toScriptValue(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
     void setParent(DataInformationBase* newParent);
     DataInformationBase* parent() const;
-    QPair<DataInformation*, QString> findChildForDynamicArrayLength(const QString& name,
-            uint upTo) const;
     ScriptLogger* logger() const;
-
-protected:
-    /**
-     *  the offset of child number @p index compared to the beginning of the structure in bits.
-     *  @param index the index of the child
-     *  @return 0 unless this DataInformation has children
+    /** just a shorthand for logger->info(this) */
+    QDebug logInfo() const;
+    /** just a shorthand for logger->warn(this) */
+    QDebug logWarn() const;
+    /** just a shorthand for logger->error(this) */
+    QDebug logError() const;
+    /** whether data was logged from here (and which level it was)
+     * @return ScriptLogger::LogInvalid if no data was logged or the level of the most severe log
      */
-    virtual BitCount32 offset(unsigned int index) const = 0;
+    ScriptLogger::LogLevel loggedData() const;
+    void setLoggedData(ScriptLogger::LogLevel lvl) const;
+
     /**
      * Find the index of a DataInformation in this object, needed to calculate the row
+     * @return the index of @p data or -1 if not found
      */
-    virtual int indexOf(const DataInformation* const data) const; //TODO make this pure virtual
+    virtual int indexOf(const DataInformation* const data) const = 0;
+protected:
     bool additionalDataNeeded(AdditionalData* data) const;
     AdditionalData* additionalData() const;
     void setAdditionalData(AdditionalData* data);
-
+    /** So that this object can be wrapped by the correct javascript object*/
+    virtual QScriptClass* scriptClass(ScriptHandlerInfo* handlerInfo) const = 0;
+    static QVariant eofReachedData(int role);
+private:
+    void setValidationError(QString errorMessage); //only called by ScriptHandler
 protected:
     bool mValidationSuccessful :1;
     bool mHasBeenValidated :1;
+    bool mHasBeenUpdated :1;
     bool mWasAbleToRead :1;
     DataInformationEndianess mByteOrder :2;
+    mutable ScriptLogger::LogLevel mLoggedData :2; //mutable is ugly but i guess it is the best solution
     QScopedPointer<AdditionalData> mAdditionalData;
     DataInformationBase* mParent;
     QString mName;
@@ -210,7 +239,7 @@ Q_DECLARE_METATYPE(DataInformation*)
 Q_DECLARE_METATYPE(const DataInformation*)
 
 inline Qt::ItemFlags DataInformation::flags(int column, bool fileLoaded) const
-        {
+{
     Q_UNUSED(column)
     Q_UNUSED(fileLoaded);
     return Qt::ItemIsSelectable | Qt::ItemIsEnabled;
@@ -227,13 +256,8 @@ inline void DataInformation::setName(const QString& newName)
 }
 
 inline DataInformation* DataInformation::childAt(unsigned int) const
-        {
-    return NULL;
-}
-
-inline bool DataInformation::hasChildren() const
 {
-    return false;
+    return NULL;
 }
 
 inline bool DataInformation::canHaveChildren() const
@@ -251,26 +275,6 @@ inline bool DataInformation::wasAbleToRead() const
     return mWasAbleToRead;
 }
 
-inline ByteOrder DataInformation::effectiveByteOrder() const
-{
-    switch (mByteOrder)
-    {
-    case EndiannessBig:
-        return ByteOrderEnumClass::BigEndian;
-    case EndianessLittle:
-        return ByteOrderEnumClass::LittleEndian;
-    case EndianessFromSettings:
-        return Kasten2::StructViewPreferences::byteOrder();
-    case EndianessInherit:
-        return (mParent && !mParent->isTopLevel()) ?
-                mParent->asDataInformation()->effectiveByteOrder() :
-                Kasten2::StructViewPreferences::byteOrder();
-    }
-
-    // here must be a return... I guess this is correct
-    return Kasten2::StructViewPreferences::byteOrder();
-}
-
 inline DataInformation::DataInformationEndianess DataInformation::byteOrder() const
 {
     return mByteOrder;
@@ -302,4 +306,44 @@ inline AdditionalData* DataInformation::additionalData() const
     return mAdditionalData.data();
 }
 
+inline QDebug DataInformation::logInfo() const
+{
+    return logger()->info(this);
+}
+
+inline QDebug DataInformation::logWarn() const
+{
+    return logger()->warn(this);
+}
+
+inline QDebug DataInformation::logError() const
+{
+    return logger()->error(this);
+}
+
+inline ScriptLogger::LogLevel DataInformation::loggedData() const
+{
+    return mLoggedData;
+}
+
+inline void DataInformation::setLoggedData(ScriptLogger::LogLevel lvl) const
+{
+    mLoggedData = lvl;
+}
+
+inline bool DataInformation::hasBeenUpdated() const
+{
+    return mHasBeenUpdated;
+}
+
+inline bool DataInformation::validationSuccessful() const
+{
+    return mValidationSuccessful;
+}
+
+inline bool DataInformation::hasBeenValidated() const
+{
+    return mHasBeenValidated;
+}
+
 #endif /* DATAINFORMATION_H_ */
