@@ -21,14 +21,16 @@
  */
 #include "uintdatainformation.h"
 
-#include <QtScript/QScriptValue>
+#include <QScriptValue>
 
 #include <KGlobal>
+#include <KLocale>
+
+#include "../../../poddecoder/typeeditors/uintspinbox.h"
 
 
 template<typename T>
-QScriptValue UIntDataInformation<T>::asScriptValue(T value, QScriptEngine* engine,
-        ScriptHandlerInfo* handlerInfo)
+QScriptValue UIntDataInformationMethods<T>::asScriptValue(T value, QScriptEngine* engine, ScriptHandlerInfo* handlerInfo)
 {
     Q_UNUSED(engine);
     Q_UNUSED(handlerInfo);
@@ -36,7 +38,7 @@ QScriptValue UIntDataInformation<T>::asScriptValue(T value, QScriptEngine* engin
 }
 
 template<>
-QScriptValue UIntDataInformation<quint64>::asScriptValue(quint64 value, QScriptEngine* engine,
+QScriptValue UIntDataInformationMethods<quint64>::asScriptValue(quint64 value, QScriptEngine* engine,
         ScriptHandlerInfo* handlerInfo)
 {
     Q_UNUSED(engine);
@@ -45,21 +47,7 @@ QScriptValue UIntDataInformation<quint64>::asScriptValue(quint64 value, QScriptE
 }
 
 template<typename T>
-QScriptValue UIntDataInformation<T>::valueAsQScriptValue() const
-{
-    return UIntDataInformation<T>::asScriptValue(UnsignedDataInformation<T>::mValue, 0, 0);
-}
-
-template<typename T>
-QString UIntDataInformation<T>::valueString() const
-{
-    if (!this->mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return UIntDataInformation<T>::valueString(UnsignedDataInformation<T>::mValue);
-}
-
-template<typename T>
-QString UIntDataInformation<T>::valueString(T value, int base)
+QString UIntDataInformationMethods<T>::staticValueString(T value, int base)
 {
     QString num = QString::number(value, base);
     if (base == 10)
@@ -85,8 +73,36 @@ QString UIntDataInformation<T>::valueString(T value, int base)
     return num;
 }
 
+template<typename T>
+inline QWidget* UIntDataInformationMethods<T>::staticCreateEditWidget(QWidget* parent)
+{
+    UIntSpinBox* ret = new UIntSpinBox(parent, PrimitiveDataInformation::unsignedDisplayBase());
+    ret->setMaximum(std::numeric_limits<T>::max());
+    return ret;
+}
+
+template<typename T>
+inline QVariant UIntDataInformationMethods<T>::staticDataFromWidget(const QWidget* w)
+{
+    const UIntSpinBox* spin = dynamic_cast<const UIntSpinBox*> (w);
+    Q_CHECK_PTR(spin);
+    if (spin)
+        return QVariant(spin->value());
+    kWarning() << "could not cast widget";
+    return QVariant();
+}
+
+template<typename T>
+inline void UIntDataInformationMethods<T>::staticSetWidgetData(T value, QWidget* w)
+{
+    UIntSpinBox* spin = dynamic_cast<UIntSpinBox*> (w);
+    Q_CHECK_PTR(spin);
+    if (spin)
+        spin->setValue(value);
+}
+
 //explicitly instantiate all valid classes (c++-faq-lite 35.12)
-template class UIntDataInformation<quint8>;
-template class UIntDataInformation<quint16>;
-template class UIntDataInformation<quint32>;
-template class UIntDataInformation<quint64>;
+template class UIntDataInformationMethods<quint8>;
+template class UIntDataInformationMethods<quint16>;
+template class UIntDataInformationMethods<quint32>;
+template class UIntDataInformationMethods<quint64>;
