@@ -22,16 +22,19 @@
 
 #include "topleveldatainformation.h"
 #include "datainformation.h"
+#include "primitive/pointerdatainformation.h"
 #include "datainformationwithchildren.h"
+
 #include "../script/scripthandler.h"
 #include "../script/scriptlogger.h"
 #include "../script/scriptengineinitializer.h"
 #include "primitivefactory.h"
-#include "../allprimitivetypes.h"
 
 #include <abstractbytearraymodel.h>
 //QtScript
-#include <QtScript/QScriptEngine>
+#include <QScriptEngine>
+
+#include <KDebug>
 
 TopLevelDataInformation::TopLevelDataInformation(DataInformation* data, ScriptLogger* logger,
         QScriptEngine* engine, const QFileInfo& structureFile)
@@ -45,8 +48,9 @@ TopLevelDataInformation::TopLevelDataInformation(DataInformation* data, ScriptLo
     if (!mLogger)
         mLogger.reset(new ScriptLogger());
 
-    if (engine)
-        mScriptHandler.reset(new ScriptHandler(engine, this));
+    if (!engine)
+        engine = ScriptEngineInitializer::newEngine();
+    mScriptHandler.reset(new ScriptHandler(engine, this));
 }
 
 TopLevelDataInformation::~TopLevelDataInformation()
@@ -55,11 +59,8 @@ TopLevelDataInformation::~TopLevelDataInformation()
 
 void TopLevelDataInformation::validate()
 {
-    kDebug() << "validation of structure " << mData->name() << "requested";
-    if (mScriptHandler)
-        mScriptHandler->validateData(mData.data());
-    else
-        kDebug() << "cannot validate" << mData->name() << "since it has no validators!";
+    logger()->info(mData.data()) << "Validation requested.";
+    mScriptHandler->validateData(mData.data());
 }
 
 QScriptEngine* TopLevelDataInformation::scriptEngine() const
@@ -72,13 +73,6 @@ void TopLevelDataInformation::resetValidationState()
     mData->resetValidationState();
 }
 
-void TopLevelDataInformation::updateElement(DataInformation* elem)
-{
-    Q_CHECK_PTR(elem);
-    if (mScriptHandler)
-        mScriptHandler->updateDataInformation(elem);
-}
-
 void TopLevelDataInformation::read(Okteta::AbstractByteArrayModel* input, Okteta::Address address,
         const Okteta::ArrayChangeMetricsList& changesList, bool forceRead)
 {
@@ -98,9 +92,19 @@ void TopLevelDataInformation::read(Okteta::AbstractByteArrayModel* input, Okteta
     quint8 bitOffset = 0;
     mData->beginRead(); //before reading set wasAbleToRead to false
     mData->resetValidationState(); //reading new data -> validation state is old
-    updateElement(mData.data()); //unlikely that this is useful, but maybe someone needs it
+    const DataInformation* oldData = mData.data();
+    mScriptHandler->updateDataInformation(mData.data()); //unlikely that this is useful, but maybe someone needs it
+    if (mData.data() != oldData)
+        mLogger->info() << "Main element was replaced!";
     mData->readData(input, address, remainingBits, &bitOffset);
 
+    // Read all the delayed PointerDataInformation
+    // We do this because the pointed data is indipendent from the
+    // structure containing the pointer and so we can use fields
+    // which come after the pointer itself in the structure
+    while (!mDelayedRead.isEmpty())
+        mDelayedRead.dequeue()->delayedReadData(input, address);
+
     if (mChildDataChanged)
     {
         emit dataChanged();
@@ -108,6 +112,11 @@ void TopLevelDataInformation::read(Okteta::AbstractByteArrayModel* input, Okteta
     }
 }
 
+void TopLevelDataInformation::enqueueReadData(PointerDataInformation *toRead)
+{
+    mDelayedRead.append(toRead);
+}
+
 bool TopLevelDataInformation::isReadingNecessary(const Okteta::ArrayChangeMetricsList& changesList,
         Okteta::Address address)
 {
@@ -205,3 +214,13 @@ int TopLevelDataInformation::indexOf(const DataInformation* const data) const
     Q_ASSERT(data == mData.data());
     return mIndex;
 }
+
+void TopLevelDataInformation::setActualDataInformation(DataInformation* newData)
+{
+    Q_CHECK_PTR(newData);
+    Q_ASSERT(!mData->hasBeenUpdated());
+    if (mData->hasBeenUpdated())
+        mLogger->error() << "Cannot replace top level element since it was already updated!";
+    else
+        mData.reset(newData);
+}
