@@ -23,12 +23,12 @@
 #ifndef DEFAULTSCRIPTCLASS_H
 #define DEFAULTSCRIPTCLASS_H
 
-#include <QtScript/QScriptClass>
-#include <QtScript/QScriptValue>
-#include <QtScript/QScriptEngine>
-#include <QtScript/QScriptString>
-#include <QtScript/QScriptClassPropertyIterator>
-#include <KDebug>
+#include <QVector>
+#include <QScriptClass>
+#include <QScriptValue>
+#include <QScriptEngine>
+#include <QScriptString>
+#include <QScriptClassPropertyIterator>
 
 class DataInformation;
 class ScriptHandlerInfo;
@@ -36,13 +36,13 @@ class ScriptHandlerInfo;
 class DefaultScriptClass : public QScriptClass
 {
     Q_DISABLE_COPY(DefaultScriptClass)
+
 public:
     typedef DataInformation* DataInfPtr;
     typedef QVector<QPair<QScriptString, QScriptValue::PropertyFlags> > PropertyInfoList;
     DefaultScriptClass(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
     virtual ~DefaultScriptClass();
-    //TODO
-    //virtual QScriptClassPropertyIterator* newIterator(const QScriptValue& object);
+
     virtual QueryFlags queryProperty(const QScriptValue& object, const QScriptString& name, QueryFlags flags, uint* id);
     virtual QScriptValue::PropertyFlags propertyFlags(const QScriptValue& object, const QScriptString& name, uint id);
     virtual QScriptValue property(const QScriptValue& object, const QScriptString& name, uint id);
@@ -60,6 +60,8 @@ protected:
     virtual bool setAdditionalProperty(DataInformation* data, const QScriptString& name, uint id, const QScriptValue& value) = 0;
     static QScriptValue Default_proto_toString(QScriptContext* ctx, QScriptEngine* eng);
 
+private:
+    void setDataType(const QScriptValue& value, DataInformation* data);
 protected:
     QScriptString s_valid;
     QScriptString s_wasAbleToRead;
@@ -67,6 +69,9 @@ protected:
     QScriptString s_parent;
     QScriptString s_byteOrder;
     QScriptString s_name;
+    QScriptString s_datatype;
+    QScriptString s_updateFunc;
+    QScriptString s_validationFunc;
     /** Contains all properties of this class, classes inheriting should add their own properties to this list */
     PropertyInfoList mIterableProperties;
     QScriptValue mDefaultPrototype;
