@@ -5,7 +5,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  *   copyright (C) 2003      Brian Thomas <thomas@mail630.gsfc.nasa.gov>   *
- *   copyright (C) 2004-2008                                               *
+ *   copyright (C) 2004-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -20,15 +20,13 @@
 #include "codedocument.h"
 #include "codegenerator.h"
 
-// kde includes
-#include <kdebug.h>
-
-OwnedHierarchicalCodeBlock::OwnedHierarchicalCodeBlock ( UMLObject *parent, CodeDocument * doc, const QString &start, const QString &end, const QString &comment)
-        : OwnedCodeBlock(parent), HierarchicalCodeBlock ( doc, start, end, comment)
+OwnedHierarchicalCodeBlock::OwnedHierarchicalCodeBlock(UMLObject *parent, CodeDocument * doc, const QString &start, const QString &end, const QString &comment)
+  : OwnedCodeBlock(parent),
+    HierarchicalCodeBlock(doc, start, end, comment)
 {
 }
 
-OwnedHierarchicalCodeBlock::~OwnedHierarchicalCodeBlock ( )
+OwnedHierarchicalCodeBlock::~OwnedHierarchicalCodeBlock()
 {
 }
 
@@ -37,7 +35,7 @@ OwnedHierarchicalCodeBlock::~OwnedHierarchicalCodeBlock ( )
  * and any other text blocks that it 'owns'.
  * needed to be called prior to deletion of the textblock.
  */
-void OwnedHierarchicalCodeBlock::release ()
+void OwnedHierarchicalCodeBlock::release()
 {
     OwnedCodeBlock::release();
     HierarchicalCodeBlock::release();
@@ -46,7 +44,7 @@ void OwnedHierarchicalCodeBlock::release ()
 /**
  * set the class attributes from a passed object
  */
-void OwnedHierarchicalCodeBlock::setAttributesFromObject (TextBlock * obj)
+void OwnedHierarchicalCodeBlock::setAttributesFromObject(TextBlock * obj)
 {
     HierarchicalCodeBlock::setAttributesFromObject(obj);
     OwnedCodeBlock::setAttributesFromObject(obj);
@@ -56,14 +54,14 @@ void OwnedHierarchicalCodeBlock::setAttributesFromObject (TextBlock * obj)
  * set attributes of the node that represents this class
  * in the XMI document.
  */
-void OwnedHierarchicalCodeBlock::setAttributesOnNode (QDomDocument & doc, QDomElement & elem )
+void OwnedHierarchicalCodeBlock::setAttributesOnNode(QDomDocument & doc, QDomElement & elem)
 {
     // set super-class attributes
     HierarchicalCodeBlock::setAttributesOnNode(doc, elem);
     OwnedCodeBlock::setAttributesOnNode(doc, elem);
 
     // set local class attributes
-    elem.setAttribute("parent_id",ID2STR(getParentObject()->getID()));
+    elem.setAttribute("parent_id",ID2STR(getParentObject()->id()));
 
     // setting ID's takes special treatment
     // as UMLRoles arent properly stored in the XMI right now.
@@ -71,7 +69,7 @@ void OwnedHierarchicalCodeBlock::setAttributesOnNode (QDomDocument & doc, QDomEl
     UMLRole * role = dynamic_cast<UMLRole*>(getParentObject());
     if(role) {
         // see comment on role_id at OwnedCodeBlock::setAttributesOnNode()
-        elem.setAttribute("role_id", (role->getRole() == Uml::A));
+        elem.setAttribute("role_id", (role->role() == Uml::A));
     }
     /* else
             elem.setAttribute("role_id","-1");
@@ -82,7 +80,7 @@ void OwnedHierarchicalCodeBlock::setAttributesOnNode (QDomDocument & doc, QDomEl
  * set the class attributes of this object from
  * the passed element node.
  */
-void OwnedHierarchicalCodeBlock::setAttributesFromNode ( QDomElement & root)
+void OwnedHierarchicalCodeBlock::setAttributesFromNode(QDomElement & root)
 {
     // set attributes from the XMI
     HierarchicalCodeBlock::setAttributesFromNode(root); // superclass load
@@ -94,20 +92,15 @@ void OwnedHierarchicalCodeBlock::setAttributesFromNode ( QDomElement & root)
  */
 CodeDocument * OwnedHierarchicalCodeBlock::getParentDocument()
 {
-
-/**
- * Return the parent code document
- */
     return TextBlock::getParentDocument();
 }
 
-void OwnedHierarchicalCodeBlock::syncToParent ( )
+void OwnedHierarchicalCodeBlock::syncToParent()
 {
-    if(getContentType() != CodeBlock::AutoGenerated)
+    if (contentType() != CodeBlock::AutoGenerated)
         return;
 
     updateContent();
 }
 
-
 #include "ownedhierarchicalcodeblock.moc"
