@@ -32,7 +32,7 @@
 #include "uml.h"
 
 // qt includes
-#include <QtCore/QRegExp>
+#include <QRegExp>
 
 RubyClassifierCodeDocument::RubyClassifierCodeDocument ( UMLClassifier * concept )
         : ClassifierCodeDocument (concept)
