@@ -37,9 +37,9 @@ namespace boost { namespace spirit { namespace classic { namespace impl {
 #include "position.h"
 
 #include <list>
-#include <QtCore/QString>
-#include <QtCore/QMap>
-#include <QtCore/QPair>
+#include <QMap>
+#include <QPair>
+#include <QString>
 #include <assert.h>
 
 #include "skip_rule.hpp"
@@ -49,7 +49,6 @@ using boost::spirit::classic::rule;
 using boost::spirit::classic::scanner;
 using boost::spirit::classic::ext::skip_rule_parser;
 
-typedef boost::spirit::classic::position_iterator<QChar const*> CharIterator;
 typedef rule<scanner<CharIterator> > SkipRule;
 typedef skip_rule_parser<SkipRule, CharIterator> CharParser;
 typedef scanner<CharIterator> CharScanner;
