@@ -28,8 +28,8 @@
 #include <kvbox.h>
 
 // qt includes
-#include <QtGui/QFrame>
-#include <QtGui/QHBoxLayout>
+#include <QFrame>
+#include <QHBoxLayout>
 
 /**
  * Constructor.
@@ -96,7 +96,7 @@ void UMLViewDialog::setupDiagramPropertiesPage()
     m_diagramProperties = new DiagramPropertiesPage(page);
 
     m_diagramProperties->ui_diagramName->setText( m_pScene->name() );
-    m_diagramProperties->ui_zoom->setValue(m_pScene->view()->currentZoom());
+    m_diagramProperties->ui_zoom->setValue(m_pScene->activeView()->currentZoom());
     m_diagramProperties->ui_showOpSigs->setChecked( m_pScene->showOpSig() );
 
     m_diagramProperties->ui_checkBoxShowGrid->setChecked(m_pScene->isSnapGridVisible());
@@ -186,7 +186,7 @@ void UMLViewDialog::applyPage(KPageWidgetItem *item)
         m_pScene->setTextColor(m_options.uiState.textColor);
         m_pScene->setLineColor(m_options.uiState.lineColor);
         m_pScene->setFillColor(m_options.uiState.fillColor);
-        m_pScene->setBackgroundColor(m_options.uiState.backgroundColor);
+        m_pScene->setBackgroundBrush(m_options.uiState.backgroundColor);
         m_pScene->setGridDotColor(m_options.uiState.gridDotColor);
         //:TODO: gridCrossColor, gridTextColor, gridTextFont, gridTextIsVisible
     }
@@ -200,7 +200,7 @@ void UMLViewDialog::applyPage(KPageWidgetItem *item)
         if ( m_pScene->type() != Uml::DiagramType::Class ) {
             return;
         }
-        m_pOptionsPage->updateUMLWidget();
+        m_pOptionsPage->apply();
         m_pScene->setClassWidgetOptions( m_pOptionsPage );
         //       sig = m_pTempWidget->getShowOpSigs();
         //       showSig = !( sig == Uml::st_NoSig || sig == Uml::st_NoSigNoVis );
@@ -236,7 +236,7 @@ void UMLViewDialog::checkName()
         else {
             // uDebug() << "Cannot find view with name " << newName;
             m_pScene->setName( newName );
-            doc->signalDiagramRenamed(m_pScene->view());
+            doc->signalDiagramRenamed(m_pScene->activeView());
         }
     }
 }
