@@ -34,7 +34,6 @@
 #include <QString>
 #include <QTemporaryFile>
 #include <QTextStream>
-#include <QtDebug>
 
 /**
  * dot specific paint engine
@@ -337,7 +336,7 @@ bool DotGenerator::createDotFile(UMLScene *scene, const QString &fileName, const
         else {
             DotPaintDevice d;
             QPainter p(&d);
-            widget->paint(p, 0, 0);
+            widget->draw(p, 0, 0);
             label = d.data().join("\\n");
         }
     
