@@ -35,16 +35,18 @@
 #include <kmessagebox.h>
 
 // qt includes
-#include <QtCore/QTextStream>
-#include <QtCore/QFile>
-#include <QtCore/QRegExp>
-#include <QtGui/QDrag>
+#include <QDrag>
+#include <QFile>
+#include <QRegExp>
+#include <QTextStream>
 
 // system includes
 #include <cstdlib>
 
 #define DBG_LVI "UMLListViewItem"
 
+DEBUG_REGISTER(UMLListViewItem)
+
 /**
  * Sets up an instance.
  *
@@ -190,7 +192,6 @@ void UMLListViewItem::init()
     m_bCreating = false;
     m_object = 0;
     m_id = Uml::id_None;
-    DEBUG_REGISTER(DBG_LVI);
 }
 
 /**
@@ -1083,11 +1084,11 @@ QString UMLListViewItem::toString(ListViewType type)
 /**
  * Overloading operator for debugging output.
  */
-QDebug operator<<(QDebug out, const UMLListViewItem& item)
+QDebug operator<<(QDebug dbg, const UMLListViewItem& item)
 {
-    out.nospace() << "UMLListViewItem: " << item.text(0)
+    dbg.nospace() << "UMLListViewItem: " << item.text(0)
         << ", type=" << UMLListViewItem::toString(item.type())
         << ", id=" << ID2STR(item.ID())
         << ", children=" << item.childCount();
-    return out.space();
+    return dbg.space();
 }
