@@ -32,7 +32,7 @@ public:
     ComponentWidget(UMLScene * scene, UMLComponent *c);
     virtual ~ComponentWidget();
 
-    virtual void paint(QPainter& p, int offsetX, int offsetY);
+    virtual void draw(QPainter& p, int offsetX, int offsetY);
 
     virtual void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
 
