@@ -50,7 +50,7 @@ Qt::Orientation ForkJoinWidget::orientation() const
 void ForkJoinWidget::setOrientation(Qt::Orientation ori)
 {
     m_orientation = ori;
-    updateComponentSize();
+    updateGeometry();
     UMLWidget::adjustAssocs( x(), y() );
 }
 
@@ -58,7 +58,7 @@ void ForkJoinWidget::setOrientation(Qt::Orientation ori)
  * Reimplemented from UMLWidget::paint to draw the plate of
  * fork join.
  */
-void ForkJoinWidget::paint(QPainter& p, int offsetX, int offsetY)
+void ForkJoinWidget::draw(QPainter& p, int offsetX, int offsetY)
 {
     p.fillRect( offsetX, offsetY, width(), height(), QBrush( Qt::black ));
 
@@ -153,7 +153,7 @@ void ForkJoinWidget::drawSelected(QPainter *, int /*offsetX*/, int /*offsetY*/)
 /**
  * Reimplement method from UMLWidget.
  */
-void ForkJoinWidget::constrain(int& width, int& height)
+void ForkJoinWidget::constrain(UMLSceneValue& width, UMLSceneValue& height)
 {
     if (m_orientation == Qt::Vertical) {
         if (width < 4)
