@@ -13,7 +13,6 @@
 
 #include "umlwidget.h"
 
-#include <QMetaEnum>
 #include <QPainter>
 #include <QStringList>
 
@@ -87,7 +86,7 @@ protected:
     UMLSceneSize maximumSize();
     void setAspectRatioMode();
 
-public slots:
+public Q_SLOTS:
     virtual void slotMenuSelection(QAction* action);
 
 private:
